GenSeq

Struct GenSeq 

pub struct GenSeq<T, Gen = u32, C = Vec<Entry<T, Gen>>>
where C: AsRef<[Entry<T, Gen>]>, Gen: IGeneration,
{ /* private fields */ }

Implementations

Source

impl<T, C, Gen> GenSeq<T, Gen, C>
where C: AsRef<[Entry<T, Gen>]>, Gen: IGeneration,

pub fn try_from_raw_parts( values: C, free: usize, ) -> Result<GenSeq<T, Gen, C>, String>
where C: AsRef<[Entry<T, Gen>]>,

pub unsafe fn from_raw_parts_unchecked( values: C, free: usize, len: usize, ) -> GenSeq<T, Gen, C>

Source

impl<T, Gen, C> GenSeq<T, Gen, C>
where C: AsRef<[Entry<T, Gen>]>, Gen: IGeneration,

pub fn new() -> GenSeq<T, Gen, C>
where C: Default,

pub fn clear(&mut self)
where C: Clear,

Clears the GenVec, removing all elements and resetting all GenID values.

After calling this method, any previous GenID is no longer valid (not enforced) and must not be used, as doing so may lead to undefined behavior.

Source

impl<T, Gen, C> GenSeq<T, Gen, C>
where C: AsRef<[Entry<T, Gen>]>, Gen: IGeneration,

pub fn as_ref<'a>(&'a self) -> GenSeq<T, Gen, &'a [Entry<T, Gen>]>

pub fn get_entry_from_index(&self, index: usize) -> Option<&Entry<T, Gen>>

pub fn get_from_index(&self, index: usize) -> Option<&T>

pub fn get_entry(&self, id: GenIDOf<T, Gen>) -> Option<&Entry<T, Gen>>

pub fn get(&self, id: GenIDOf<T, Gen>) -> Option<&T>

pub fn index_to_id(&self, index: usize) -> GenIDOf<T, Gen>

Return a valid GenID to the current index or return GenIDOf::NULL if the index is outside the range

pub fn entries( &self, ) -> impl Iterator<Item = &Entry<T, Gen>> + DoubleEndedIterator + FusedIterator

pub const fn len(&self) -> usize

pub fn iter(&self) -> Iter<'_, T, Gen>

pub fn ids(&self) -> impl Iterator<Item = GenIDOf<T, Gen>>

pub fn values(&self) -> impl Iterator<Item = &T>

pub fn into_ids(self) -> impl Iterator<Item = GenIDOf<T, Gen>>
where C: IntoIterator<Item = Entry<T, Gen>>,

pub fn into_values(self) -> impl Iterator<Item = T>
where C: IntoIterator<Item = Entry<T, Gen>>,

pub fn iter_index(&self) -> impl Iterator<Item = usize> + 'static

Iter over all entry index, including the free/unused one.

The correct way to iterate over all entry index.

Use this instead of 0..genvec.len() (wrong).

pub fn to_owned(&self) -> GenSeq<T, Gen, <C as ToOwned>::Owned>
where C: ToOwned, <C as ToOwned>::Owned: AsRef<[Entry<T, Gen>]>,

Source

impl<T, Gen, C> GenSeq<T, Gen, C>
where C: AsRef<[Entry<T, Gen>]> + AsMut<[Entry<T, Gen>]>, Gen: IGeneration,

pub fn as_mut<'a>(&'a mut self) -> GenSeq<T, Gen, &'a mut [Entry<T, Gen>]>

pub fn remove_all(&mut self)

Removes all elements from the GenVec and invalidates all existing GenID (enforced).

pub fn rollback_insert(&mut self, id: GenIDOf<T, Gen>) -> Result<T, ()>
where C: Pop<Entry<T, Gen>>,

pub fn try_insert_cyclic<F>( &mut self, init: F, ) -> Result<GenIDOf<T, Gen>, <C as TryPush<Entry<T, Gen>>>::Error>
where F: FnOnce(GenIDOf<T, Gen>) -> T, C: TryPush<Entry<T, Gen>>,

pub fn try_insert( &mut self, value: T, ) -> Result<GenIDOf<T, Gen>, <C as TryPush<Entry<T, Gen>>>::Error>
where C: TryPush<Entry<T, Gen>>,

pub fn insert_cyclic<F>(&mut self, init: F) -> GenIDOf<T, Gen>
where F: FnOnce(GenIDOf<T, Gen>) -> T, C: Push<Entry<T, Gen>>,

pub fn insert(&mut self, value: T) -> GenIDOf<T, Gen>
where C: Push<Entry<T, Gen>>,

pub fn get_mut_from_index(&mut self, index: usize) -> Option<&mut T>

pub fn get_mut(&mut self, id: GenIDOf<T, Gen>) -> Option<&mut T>

pub fn rollback_remove_index( &mut self, index: usize, value: T, ) -> Result<(), ()>

The operation that once done just after an Self::remove_from_index, put this data structure in the same state as before

pub fn remove_from_index(&mut self, index: usize) -> Option<T>

pub fn rollback_remove( &mut self, id: GenIDOf<T, Gen>, value: T, ) -> Result<(), ()>

pub fn remove(&mut self, id: GenIDOf<T, Gen>) -> Option<T>

pub fn iter_mut(&mut self) -> IterMut<'_, T, Gen>

pub fn values_mut(&mut self) -> impl Iterator<Item = &mut T>

pub fn retain<F>(&mut self, f: F)
where F: FnMut(GenIDOf<T, Gen>, &T) -> bool,

Retains only the elements specified by the predicate.

In other words, remove all pairs (id, v) for which f(id, &v) returns false. The elements are visited in unsorted (and unspecified) order.

pub fn retain_mut<F>(&mut self, f: F)
where F: FnMut(GenIDOf<T, Gen>, &mut T) -> bool,

Retains only the elements specified by the predicate.

In other words, remove all pairs (id, v) for which f(id, &mut v) returns false. The elements are visited in unsorted (and unspecified) order.

Source

impl<T, Gen, C> GenSeq<T, Gen, C>
where C: AsRef<[Entry<T, Gen>]>, Gen: IGeneration,

pub fn append<C2>( &mut self, other: &mut GenSeq<T, Gen, C2>, ) -> impl GenIDUpdater<T, Gen> + 'static
where T: GenIDUpdatable<T, Gen> + 'static, C: AsRef<[Entry<T, Gen>]> + AsMut<[Entry<T, Gen>]> + Push<Entry<T, Gen>>, C2: AsRef<[Entry<T, Gen>]> + AsMut<[Entry<T, Gen>]> + Clear,

Moves all the elements of other into self, leaving other empty by clearing it (don’t invalidate all previous GenID).