pub struct Blas { /* private fields */ }Expand description
Bottom Level Acceleration Structure (BLAS).
A BLAS is a device-specific raytracing acceleration structure that contains geometry data.
These BLASes are combined with transform in a TlasInstance to create a Tlas.
Implementations
Sourceimpl Blas
impl Blas
Sourcepub fn handle(&self) -> Option<u64>
pub fn handle(&self) -> Option<u64>
Raw handle to the acceleration structure, used inside raw instance buffers.
Sourcepub unsafe fn as_hal<A, F, R>(&mut self, hal_blas_callback: F) -> R
pub unsafe fn as_hal<A, F, R>(&mut self, hal_blas_callback: F) -> R
Returns the inner hal Acceleration Structure using a callback. The hal acceleration structure
will be None if the backend type argument does not match with this wgpu Blas
This method will start the wgpu_core level command recording.
Safety
- The raw handle obtained from the hal Acceleration Structure must not be manually destroyed