pub struct Tlas { /* private fields */ }Expand description
Top Level Acceleration Structure (TLAS).
A TLAS contains a series of TLAS instances, which are a reference to a BLAS and a transformation matrix placing the geometry in the world.
A TLAS contains TLAS instances in a device readable form, you cant interact directly with these, instead you have to build the TLAS with TLAS instances.
Implementations
Sourceimpl Tlas
impl Tlas
Sourcepub unsafe fn as_hal<A, F, R>(&mut self, hal_tlas_callback: F) -> R
pub unsafe fn as_hal<A, F, R>(&mut self, hal_tlas_callback: F) -> R
Returns the inner hal Acceleration Structure using a callback. The hal acceleration structure
will be None if the backend type argument does not match with this wgpu Tlas
This method will start the wgpu_core level command recording.
Safety
- The raw handle obtained from the hal Acceleration Structure must not be manually destroyed
- If the raw handle is build,