pub struct Id<T>(/* private fields */)
where
T: Marker;Expand description
An identifier for a wgpu object.
An Id<T> value identifies a value stored in a Global’s Hub.
Note on Id typing
You might assume that an Id<T> can only be used to retrieve a resource of
type T, but that is not quite the case. The id types in wgpu-core’s
public API (TextureId, for example) can refer to resources belonging to
any backend, but the corresponding resource types (Texture<A>, for
example) are always parameterized by a specific backend A.
So the T in Id<T> is usually a resource type like Texture<Noop>,
where Noop is the wgpu_hal dummy back end. These empty types are
never actually used, beyond just making sure you access each Storage with
the right kind of identifier. The members of Hub<A> pair up each
X<Noop> type with the resource type X<A>, for some specific backend
A.
Implementations
Sourceimpl Id<CommandEncoder>
impl Id<CommandEncoder>
pub fn into_command_buffer_id(self) -> Id<CommandBuffer>
Sourceimpl Id<CommandBuffer>
impl Id<CommandBuffer>
pub fn into_command_encoder_id(self) -> Id<CommandEncoder>