pub struct VertexStep {
pub stride: u64,
pub last_stride: u64,
pub mode: VertexStepMode,
}Expand description
How a render pipeline will retrieve attributes from a particular vertex buffer.
Fields
stride: u64The byte stride in the buffer between one attribute value and the next.
last_stride: u64The byte size required to fit the last vertex in the stream.
mode: VertexStepModeWhether the buffer is indexed by vertex number or instance number.