Module iter

Module iter 

Structs

CapacityFullError
WrongLenError

Traits

IterExtension
IterMutExtension
IterPredicate
Product
Trait to represent types that can be created by multiplying elements of an iterator.
Sum
Trait to represent types that can be created by summing up an iterator.
TryFromIterator
A trait to create a value from an iterator.