macro_rules! map_on_std_fmt_without_debug {
($($macro_arms:tt)*) => { ... };
}Expand description
Macro for mapping over all standard formatting traits except [std::fmt::Debug]:
- Display
- Octal
- LowerHex
- UpperHex
- Pointer
- Binary
- LowerExp
- UpperExp
macro_rules! map_on_std_fmt_without_debug {
($($macro_arms:tt)*) => { ... };
}Macro for mapping over all standard formatting traits except [std::fmt::Debug]: