RectangleOf

Struct RectangleOf 

#[repr(C)]
pub struct RectangleOf<T> { pub pos: T, pub size: T, }
A N dimension rectangle

Fields

pos: Tsize: T

Implementations

Source

impl<T> RectangleOf<T>

pub const LEN: usize = 2usize

pub const fn from_array(array: [T; 2]) -> RectangleOf<T>

pub const fn to_array(self) -> [T; 2]

pub const fn array(&self) -> &[T; 2]

pub const fn array_mut(&mut self) -> &mut [T; 2]

pub fn max(self, other: RectangleOf<T>) -> RectangleOf<T>
where RectangleOf<T>: Max,

Max function in a component way

Can cause a panic for grid if the size mismatch

pub fn min(self, other: RectangleOf<T>) -> RectangleOf<T>
where RectangleOf<T>: Min,

Min function in a component way

Can cause a panic for grid if the size mismatch

pub fn abs(self) -> <RectangleOf<T> as Abs>::Output
where RectangleOf<T>: Abs,

Absolute value in a component way.

Overflow behavior

The absolute value of iX::MIN cannot be represented as an iX, and attempting to calculate it will cause an overflow. This means that code in debug mode will trigger a panic on this case and optimized code will return iX::MIN without a panic.

Can cause a panic for grid if the size mismatch

pub fn mix<C>(self, other: RectangleOf<T>, coef: C) -> RectangleOf<T>
where RectangleOf<T>: Mix<C>, C: Float,

Mix function in a component way

The coef is clamped between 0.0..1.

  1. => self,
  2. => dest.

Can cause a panic for grid if the size mismatch

pub fn mix_unchecked<C>(self, other: RectangleOf<T>, coef: C) -> RectangleOf<T>
where RectangleOf<T>: Mix<C>, C: Float,

Mix function in a component way

The coef is not clamped between 0.0..1.

  1. => self,
  2. => dest.

Can cause a panic for grid if the size mismatch

pub fn clamp( self, min_val: RectangleOf<T>, max_val: RectangleOf<T>, ) -> RectangleOf<T>
where RectangleOf<T>: Clamp,

Clamp function in a component way

Clamps self between min_val and max_val (inclusive)

Can cause a panic for grid if the size mismatch

Source

impl<T> RectangleOf<T>
where T: Number,

Source

impl<T> RectangleOf<Vector<T, 2>>
where T: Number,

pub fn down_left(&self) -> Vector<T, 2>

pub fn down_right(&self) -> Vector<T, 2>
where T: One + Mul<Output = T> + Add<Output = T>,

pub fn bottom_left(&self) -> Vector<T, 2>

Same as down_left()

pub fn bottom_right(&self) -> Vector<T, 2>
where T: One + Mul<Output = T> + Add<Output = T>,

Same as down_right()

pub fn up_right(&self) -> Vector<T, 2>
where T: Add<Output = T>,

pub fn up_left(&self) -> Vector<T, 2>
where T: One + Mul<Output = T> + Add<Output = T>,

pub fn top_right(&self) -> Vector<T, 2>
where T: Add<Output = T>,

Same as up_right()

pub fn top_left(&self) -> Vector<T, 2>
where T: One + Mul<Output = T> + Add<Output = T>,

Same as up_left()

Source

impl<T, const N: usize> RectangleOf<Vector<T, N>>
where Vector<T, N>: Number, T: Number,

pub fn new_centered( pos_middle: Vector<T, N>, size: Vector<T, N>, ) -> RectangleOf<Vector<T, N>>

pub fn new_with_center( bottom_left: Vector<T, N>, size: Vector<T, N>, center_coef: Vector<T, N>, ) -> RectangleOf<Vector<T, N>>

pub fn get_coef(&self, coef: Vector<T, N>) -> Vector<T, N>
where Vector<T, N>: Arithmetic,

pub fn middle(&self) -> Vector<T, N>

The center of the coordinate, whatever the dimension

pub fn center(&self) -> Vector<T, N>

pub fn middle_right(&self) -> Vector<T, N>
where Vector<T, N>: HaveX<T>,

pub fn middle_left(&self) -> Vector<T, N>
where Vector<T, N>: HaveX<T>,

pub fn middle_up(&self) -> Vector<T, N>
where Vector<T, N>: HaveY<T>,

pub fn middle_down(&self) -> Vector<T, N>
where Vector<T, N>: HaveY<T>,

pub fn middle_forward(&self) -> Vector<T, N>
where Vector<T, N>: HaveZ<T>,

pub fn middle_backward(&self) -> Vector<T, N>
where Vector<T, N>: HaveZ<T>,

pub fn middle_ana(&self) -> Vector<T, N>
where Vector<T, N>: HaveW<T>,

pub fn middle_kata(&self) -> Vector<T, N>
where Vector<T, N>: HaveW<T>,

pub fn right_value(&self) -> T
where Vector<T, N>: HaveX<T>,

pub fn left_value(&self) -> T
where Vector<T, N>: HaveX<T>,

pub fn up_value(&self) -> T
where Vector<T, N>: HaveY<T>,

pub fn down_value(&self) -> T
where Vector<T, N>: HaveY<T>,

pub fn top_value(&self) -> T
where Vector<T, N>: HaveY<T>,

Same as up_value()

pub fn bottom_value(&self) -> T
where Vector<T, N>: HaveY<T>,

Same as down_value()

pub fn forward_value(&self) -> T
where Vector<T, N>: HaveZ<T>,

pub fn backward_value(&self) -> T
where Vector<T, N>: HaveZ<T>,

pub fn ana_value(&self) -> T
where Vector<T, N>: HaveW<T>,

pub fn kata_value(&self) -> T
where Vector<T, N>: HaveW<T>,

Source

impl<T, const N: usize> RectangleOf<Vector<T, N>>
where T: Primitive,

pub fn split_axis( &self, nb: T, axis: usize, ) -> impl Iterator<Item = RectangleOf<Vector<T, N>>>

pub fn split_x(&self, nb: T) -> impl Iterator<Item = RectangleOf<Vector<T, N>>>
where Vector<T, N>: HaveX<T>,

pub fn split_y(&self, nb: T) -> impl Iterator<Item = RectangleOf<Vector<T, N>>>
where Vector<T, N>: HaveY<T>,

pub fn split_z(&self, nb: T) -> impl Iterator<Item = RectangleOf<Vector<T, N>>>
where Vector<T, N>: HaveZ<T>,

pub fn split_w(&self, nb: T) -> impl Iterator<Item = RectangleOf<Vector<T, N>>>
where Vector<T, N>: HaveW<T>,

pub fn split_min( &self, nb: T, ) -> impl Iterator<Item = RectangleOf<Vector<T, N>>>

pub fn split_max( &self, nb: T, ) -> impl Iterator<Item = RectangleOf<Vector<T, N>>>

Source

impl<T, const N: usize> RectangleOf<Vector<T, N>>
where T: Number,

pub fn is_inside(&self, point: Vector<T, N>) -> bool

Check if a point inside the rectangle. Also work for indexing

use hexga_math::prelude::*;

// inside :
assert!(rect2i(0, 0, 2, 2).is_inside(point2(1, 1)));
assert!(rect2i(0, 0, 2, 2).is_inside(point2(0, 0)));


// not inside :
assert!(!rect2i(0, 0, 2, 2).is_inside(point2(2, 0)));
assert!(!rect2i(0, 0, 2, 2).is_inside(point2(0, 2)));
assert!(!rect2i(0, 0, 2, 2).is_inside(point2(2, 2)));

assert!(!rect2i(0, 0, 2, 2).is_inside(point2( 3,   3)));
assert!(!rect2i(0, 0, 2, 2).is_inside(point2(-1,  -1)));
assert!(!rect2i(0, 0, 2, 2).is_inside(point2(-1,  -1)));
assert!(!rect2i(0, 0, 2, 2).is_inside(point2( 1,  10)));
assert!(!rect2i(0, 0, 2, 2).is_inside(point2( 1, -10)));
assert!(!rect2i(0, 0, 2, 2).is_inside(point2(-10,  1)));
assert!(!rect2i(0, 0, 2, 2).is_inside(point2( 10,  1)));
pub fn is_inside_inclusif(&self, point: Vector<T, N>) -> bool

Check if a point inside the rectangle. Don’t work for indexing

pub fn is_rect_inside(&self, rect: RectangleOf<Vector<T, N>>) -> bool

pub fn is_empty(&self) -> bool

pub fn clamp_vector(&self, vector: Vector<T, N>) -> Vector<T, N>
where Vector<T, N>: Clamp,

pub fn intersect_or_empty( self, other: RectangleOf<Vector<T, N>>, ) -> RectangleOf<Vector<T, N>>
where Vector<T, N>: Max + Min,

pub fn intersect( self, other: RectangleOf<Vector<T, N>>, ) -> Option<RectangleOf<Vector<T, N>>>
where Vector<T, N>: Max + Min,

None if any rectangle is empty

Source

impl<T> RectangleOf<T>

pub const fn new(pos: T, size: T) -> RectangleOf<T>

assume the size is valid

pub const fn new_sized(size: T) -> RectangleOf<T>
where T: Zero,

assume the size is valid

Source

impl<T, const N: usize> RectangleOf<Vector<T, N>>
where T: Number,

pub fn from_pos_to_pos( start_pos: Vector<T, N>, end_pos: Vector<T, N>, ) -> RectangleOf<Vector<T, N>>