AngleOf

Struct AngleOf 

pub struct AngleOf<T>(/* private fields */);
2D Angle, support degree, radian, turn…

Provides conversion to other angle units

Implementations

Source

impl<T> AngleOf<T>

pub unsafe fn inner_value(self) -> T

Return the inner value. Unsafe because it expose the inner value, but the unit is not specified and may change

pub const unsafe fn from_inner_value(inner_value: T) -> AngleOf<T>

Create from the inner value. Unsafe because it expose the inner value, but the unit is not specified and may change

Source

impl<T> AngleOf<T>
where T: Float,

pub const FULL: AngleOf<T>

360°

pub const HALF: AngleOf<T>

180°

pub const FLAT: AngleOf<T>

180°

pub const RIGHT: AngleOf<T>

90°

pub fn from_radian(rad: T) -> AngleOf<T>

pub fn from_degree(degree: T) -> AngleOf<T>

pub fn from_turn(coef: T) -> AngleOf<T>

pub fn radian(self) -> T

pub fn degree(self) -> T

pub fn turn(self) -> T

pub fn normalized_positive(self) -> AngleOf<T>

[0, 2PI[

pub fn normalized(self) -> AngleOf<T>

]PI; PI]

pub fn cos_sin(self) -> (T, T)

(cos(self), sin(self))

pub fn sin_cos(self) -> (T, T)

(sin(self), cos(self))

pub fn cos_cos(self) -> (T, T)

(cos(self), cos(self))

pub fn sin_sin(self) -> (T, T)

(sin(self), sin(self))

pub fn cos(self) -> T

Cosine of the angle.

pub fn cosh(self) -> T

Hyperbolic cosine.

pub fn sin(self) -> T

Sine of the angle.

pub fn sinh(self) -> T

Hyperbolic sine.

pub fn cot(self) -> T

Cotangent (1 / tan(self)).

pub fn tan(self) -> T

Tangent of the angle.

pub fn tanh(self) -> T

Hyperbolic tangent.

pub fn to_vec2_normalized(self) -> Vector<f32, 2>
where T: Into<f32>,

Return a normalized (length = 1) vector with the same angle

pub fn to_vec2(self, length: T) -> Vector<f32, 2>
where T: Into<f32>,

pub fn to_vector2_normalized(self) -> Vector<T, 2>

Return a normalized (length = 1) vector with the same angle

pub fn to_vector2(self, length: T) -> Vector<T, 2>

pub fn inside_range(self, begin: AngleOf<T>, end: AngleOf<T>) -> bool