NonEmptyStack

Struct NonEmptyStack 

pub struct NonEmptyStack<T> { /* private fields */ }
A stack that ALWAYS have at least one element.

Implementations

Source

impl<T> NonEmptyStack<T>

A stack that always have at least one element, where the last element can be frequently accessed

pub const fn new(value: T) -> NonEmptyStack<T>

pub fn with_capacity(value: T, capacity: usize) -> NonEmptyStack<T>

pub fn from_vec(stack: Vec<T>) -> Option<NonEmptyStack<T>>

pub fn len(&self) -> usize

pub const fn last(&self) -> &T

pub const fn last_mut(&mut self) -> &mut T

pub fn clear_and_keep_last(&mut self)

Clear the stack and keep the last element

use hexga_utils::prelude::*;

let mut stack = NonEmptyStack::from_vec(vec![1,2,3,4]).unwrap();
stack.clear_and_keep_last();
assert_eq!(stack.len(), 1);
assert_eq!(stack.last(), &4);
pub fn clear_and_keep_first(&mut self)

Clear the stack and keep the first element

use hexga_utils::prelude::*;

let mut stack = NonEmptyStack::from_vec(vec![1,2,3,4]).unwrap();
stack.clear_and_keep_first();
assert_eq!(stack.len(), 1);
assert_eq!(stack.last(), &1);
pub fn clear_and_keep(&mut self, value: T)

Clear the stack and keep passed value

pub fn clear(&mut self)
where T: Default,

Clear the stack and keep defaut value

pub fn replace(&mut self, value: T) -> T

Replace the last value

pub fn push(&mut self, value: T)

pub fn duplicate(&mut self) -> &mut NonEmptyStack<T>
where T: Clone,

Clone the last element and push it

pub fn pop(&mut self) -> Option<T>

pub fn iter(&self) -> NonEmptyStackIter<'_, T>

pub fn iter_mut(&mut self) -> NonEmptyStackIterMut<'_, T>

pub fn into_values(self) -> Vec<T>