WindowButton

Enum WindowButton 

#[repr(u8)]
pub enum WindowButton { Close = 0, Minimize = 1, Maximize = 2, }

Variants



Close = 0



Minimize = 1



Maximize = 2

Implementations

Source

impl WindowButton

pub const ALL: [Self; 3]

Can’t be indexed with Self::X as usize because all the used bit flags are not necessary contiguous

pub const BITS: [WindowButtonFlags; 3]

Can’t be indexed with Self::X as usize because all the used bit flags are not necessary contiguous

pub const All: WindowButtonFlags

pub const fn index(self) -> usize

The bit index

pub const fn flags(self) -> WindowButtonFlags

pub const fn bits(self) -> u8

pub fn from_index(index: u8) -> Option<Self>

pub unsafe fn from_index_unchecked(index: u8) -> Option<Self>

pub fn from_flags(flags: WindowButtonFlags) -> Option<Self>

pub unsafe fn from_flags_unchecked(flags: WindowButtonFlags) -> Self

pub fn from_bits(bits: u8) -> Option<Self>

pub unsafe fn from_bits_unchecked(bits: u8) -> Self