pub enum WindowLevel {
AlwaysOnBottom,
Normal,
AlwaysOnTop,
}Expand description
A window level groups windows with respect to their z-position.
The relative ordering between windows in different window levels is fixed. The z-order of a window within the same window level may change dynamically on user interaction.
Platform-specific
- iOS / Android / Web / Wayland: Unsupported.
Variants
AlwaysOnBottom
The window will always be below normal windows.
This is useful for a widget-based app.
Normal
The default.
AlwaysOnTop
The window will always be on top of normal windows.