pub struct GenSeq<T, Gen = u32, C = Vec<Entry<T, Gen>>>{ /* private fields */ }Implementations
Sourceimpl<T, Gen, C> GenSeq<T, Gen, C>
impl<T, Gen, C> GenSeq<T, Gen, C>
pub fn as_ref<'a>(&'a self) -> GenSeq<T, Gen, &'a [Entry<T, Gen>]>
pub fn get_entry_from_index(&self, index: usize) -> Option<&Entry<T, Gen>>
pub fn get_from_index(&self, index: usize) -> Option<&T>
pub fn get_entry(&self, id: GenIDOf<T, Gen>) -> Option<&Entry<T, Gen>>
pub fn get(&self, id: GenIDOf<T, Gen>) -> Option<&T>
Sourcepub fn index_to_id(&self, index: usize) -> GenIDOf<T, Gen>
pub fn index_to_id(&self, index: usize) -> GenIDOf<T, Gen>
Return a valid GenID to the current index or return GenIDOf::NULL if the index is outside the range
pub fn entries( &self, ) -> impl Iterator<Item = &Entry<T, Gen>> + DoubleEndedIterator + FusedIterator
pub const fn len(&self) -> usize
pub fn iter(&self) -> Iter<'_, T, Gen> ⓘ
pub fn ids(&self) -> impl Iterator<Item = GenIDOf<T, Gen>>
pub fn values(&self) -> impl Iterator<Item = &T>
pub fn into_ids(self) -> impl Iterator<Item = GenIDOf<T, Gen>>where
C: IntoIterator<Item = Entry<T, Gen>>,
pub fn into_values(self) -> impl Iterator<Item = T>where
C: IntoIterator<Item = Entry<T, Gen>>,
Sourcepub fn iter_index(&self) -> impl Iterator<Item = usize> + 'static
pub fn iter_index(&self) -> impl Iterator<Item = usize> + 'static
Iter over all entry index, including the free/unused one.
The correct way to iterate over all entry index.
Use this instead of 0..genvec.len() (wrong).
pub fn to_owned(&self) -> GenSeq<T, Gen, <C as ToOwned>::Owned>
Sourceimpl<T, Gen, C> GenSeq<T, Gen, C>
impl<T, Gen, C> GenSeq<T, Gen, C>
pub fn as_mut<'a>(&'a mut self) -> GenSeq<T, Gen, &'a mut [Entry<T, Gen>]>
Sourcepub fn remove_all(&mut self)
pub fn remove_all(&mut self)
pub fn rollback_insert(&mut self, id: GenIDOf<T, Gen>) -> Result<T, ()>
pub fn try_insert_cyclic<F>( &mut self, init: F, ) -> Result<GenIDOf<T, Gen>, <C as TryPush<Entry<T, Gen>>>::Error>
pub fn try_insert( &mut self, value: T, ) -> Result<GenIDOf<T, Gen>, <C as TryPush<Entry<T, Gen>>>::Error>
pub fn insert_cyclic<F>(&mut self, init: F) -> GenIDOf<T, Gen>
pub fn insert(&mut self, value: T) -> GenIDOf<T, Gen>
pub fn get_mut_from_index(&mut self, index: usize) -> Option<&mut T>
pub fn get_mut(&mut self, id: GenIDOf<T, Gen>) -> Option<&mut T>
Sourcepub fn rollback_remove_index(
&mut self,
index: usize,
value: T,
) -> Result<(), ()>
pub fn rollback_remove_index( &mut self, index: usize, value: T, ) -> Result<(), ()>
The operation that once done just after an Self::remove_from_index, put this data structure in the same state as before
pub fn remove_from_index(&mut self, index: usize) -> Option<T>
pub fn rollback_remove( &mut self, id: GenIDOf<T, Gen>, value: T, ) -> Result<(), ()>
pub fn remove(&mut self, id: GenIDOf<T, Gen>) -> Option<T>
pub fn iter_mut(&mut self) -> IterMut<'_, T, Gen> ⓘ
pub fn values_mut(&mut self) -> impl Iterator<Item = &mut T>