pub struct SingleThreadCell<T> { /* private fields */ }Expand description
A value that can be read and written by only one thread.
Ownership is granted to the first thread that accesses it, first come, first served. Once a thread owns the value, no other thread can read or modify it.
Even though SingleThread<T> implements Sync and Send, it can only be accessed
by the first thread that uses it. Any attempt to access it from a different thread will fail.
Implementations
Sourceimpl<T> SingleThreadCell<T>
impl<T> SingleThreadCell<T>
pub const fn new(value: T) -> SingleThreadCell<T>