Structs
Traits
- Iter
Extension - Iter
MutExtension - Iter
Predicate - Product
- Trait to represent types that can be created by multiplying elements of an iterator.
- Sum
- Trait to represent types that can be created by summing up an iterator.
- TryFrom
Iterator - A trait to create a value from an iterator.