pub struct AngleOf<T>(/* private fields */);Expand description
2D Angle, support degree, radian, turn…
Provides conversion to other angle units
Implementations
Sourceimpl<T> AngleOf<T>
impl<T> AngleOf<T>
Sourcepub unsafe fn inner_value(self) -> T
pub unsafe fn inner_value(self) -> T
Return the inner value. Unsafe because it expose the inner value, but the unit is not specified and may change
Sourcepub const unsafe fn from_inner_value(inner_value: T) -> AngleOf<T>
pub const unsafe fn from_inner_value(inner_value: T) -> AngleOf<T>
Create from the inner value. Unsafe because it expose the inner value, but the unit is not specified and may change
Sourceimpl<T> AngleOf<T>where
T: Float,
impl<T> AngleOf<T>where
T: Float,
pub fn from_radian(rad: T) -> AngleOf<T>
pub fn from_degree(degree: T) -> AngleOf<T>
pub fn from_turn(coef: T) -> AngleOf<T>
pub fn radian(self) -> T
pub fn degree(self) -> T
pub fn turn(self) -> T
Sourcepub fn normalized_positive(self) -> AngleOf<T>
pub fn normalized_positive(self) -> AngleOf<T>
[0, 2PI[
Sourcepub fn normalized(self) -> AngleOf<T>
pub fn normalized(self) -> AngleOf<T>
]PI; PI]
Sourcepub fn to_vec2_normalized(self) -> Vector<f32, 2>
pub fn to_vec2_normalized(self) -> Vector<f32, 2>
Return a normalized (length = 1) vector with the same angle
pub fn to_vec2(self, length: T) -> Vector<f32, 2>
Sourcepub fn to_vector2_normalized(self) -> Vector<T, 2>
pub fn to_vector2_normalized(self) -> Vector<T, 2>
Return a normalized (length = 1) vector with the same angle
pub fn to_vector2(self, length: T) -> Vector<T, 2>
pub fn inside_range(self, begin: AngleOf<T>, end: AngleOf<T>) -> bool